@@ -2,15 +2,15 @@ use 5.008;
 use strict;
 use warnings;
 
+package CommonMark;
+
 use XSLoader;
 
 BEGIN {
-    our $VERSION = '0.280301';
+    our $VERSION = '0.290000';
     XSLoader::load('CommonMark', $VERSION);
 }
 
-package CommonMark;
-
 use Exporter 'import';
 our %EXPORT_TAGS = (
     opt => [ qw(
@@ -22,6 +22,7 @@ our %EXPORT_TAGS = (
         OPT_NORMALIZE
         OPT_VALIDATE_UTF8
         OPT_SMART
+        OPT_UNSAFE
     ) ],
     node => [ qw(
         NODE_NONE
@@ -81,6 +82,7 @@ my @option_map = (
     normalize     => OPT_NORMALIZE,
     validate_utf8 => OPT_VALIDATE_UTF8,
     smart         => OPT_SMART,
+    unsafe        => OPT_UNSAFE,
 );
 
 sub parse {
@@ -343,7 +345,9 @@ sub render {
         return $self->$method($render_opts);
     }
     if ($format =~ /^(commonmark|latex|man)\z/) {
-        return $self->$method($render_opts, $opts{width});
+        my $width = $opts{width};
+        $width = 0 if !defined($width);
+        return $self->$method($render_opts, $width);
     }
 
     die("invalid format '$format'");
